/**
 ****************************************************************************
 * @file	D_Para_ch0.h
 * @brief	Motor vector control Parameter Header File for CH0
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2019
 *****************************************************************************
 */
#ifndef _D_PARA_CH0_H
#define _D_PARA_CH0_H

#undef	__TYPE_LOW_VOLT
#undef	__TYPE_HIGH_VOLT

/*===================================================================*
	  Select Board type (Only valid in V7R board)
 *===================================================================*/
#define	__TYPE_LOW_VOLT									/* Low voltage board */
//#define	__TYPE_HIGH_VOLT							/* High voltage board */

/*===================================================================*
	  Select parts
 *===================================================================*/
//#define		__USE_ENCODER_CH0							/* If define __USE_ENCODER, use encoder */
//#define		__USE_INAMP_CH0								/* if define __USE_INAMP,use OPAMP */

/*===================================================================*
	  Board Parameter Definition
 *===================================================================*/
/******** NASP-V7R Low voltage board ***********************/
#if defined(__TYPE_LOW_VOLT)
  /* High/Low side driver logic */
  #define	cPOLH_CH0				(1)					/* High side	 0:Low active, 1:High active */
  #define	cPOLL_CH0				(1)					/* Low	side	 0:Low active, 1:High active */

  /* V MAX */
  #define	cV_MAX_CH0				(100.0f)			/* [V] Input voltage(Vdc)  at ADC =0xFFF0(5V) */

  /* A MAX */
  #define	cA_MAX_CH0				(10.0f)				/* [A] Input current(Iabc) at ADC =0xFFF0(5V) */

/******** NASP-V7R High voltage board **********************/
#elif defined(__TYPE_HIGH_VOLT)
  /* High/Low side driver logic */
  #define	cPOLH_CH0				(1)					/* High side	 0:Low active, 1:High active */
  #define	cPOLL_CH0				(0)					/* Low	side	 0:Low active, 1:High active */

  /* V MAX */
  #define	cV_MAX_CH0				(473.0f)			/* [V] Input voltage(Vdc)  at ADC =0xFFF0(5V) */

  /* A MAX */
  #define	cA_MAX_CH0				(11.36f)			/* [A] Input current(Iabc) at ADC =0xFFF0(5V) */
#endif


/* Current detection Type */
#define	cSHUNT_TYPE_CH0 			(3)					/* 1 : 1-shunt, 3 : 3-shunt */
#define	cBOOT_TYPE_CH0				(cBoot_i) 			/* cBoot_i : Current control, cBoot_v: Volt control */

#define	cSHUNT_ZERO_OFFSET_CH0		(2.5f)				/* [V] Shunt ad offset voltage (shunt ad voltage of 0A) */

/* AD Channel */
#if !defined(__USE_INAMP_CH0)
  #define	cADCH_CURRENT_U_CH0		(0)					/* AD channel for U-phase current of 3shunt */
  #define	cADCH_CURRENT_V_CH0		(3)					/* AD channel for V-phase current of 3shunt */
  #define	cADCH_CURRENT_W_CH0		(6)					/* AD channel for W-phase current of 3shunt */
  #define	cADCH_CURRENT_IDC_CH0	(6)					/* AD Channel for DC current of 1shunt */
#else
  #define	cADCH_CURRENT_U_CH0		(0)					/* AD channel for U-phase current of 3shunt */
  #define	cADCH_CURRENT_V_CH0		(3)					/* AD channel for V-phase current of 3shunt */
  #define	cADCH_CURRENT_W_CH0		(6)					/* AD channel for W-phase current of 3shunt */
  #define	cADCH_CURRENT_IDC_CH0	(6)					/* AD Channel for DC current of 1shunt */
#endif /* __USE_INAMP_CH0 */

#define	cADCH_VDC_CH0			    (1)					/* AD Channel for power supply voltage */

/* Over current */
#define	cOVC_CH0					(5.00f)				/* [A] Over current  */

/* Over voltage */
#define	cVDC_MINLIM_CH0				(1.0f)				/* [V] Vdc min limit */
#define	cVDC_MAXLIM_CH0				(cV_MAX_CH0 - 1.0f)	/* [V] Vdc max limit */

/*===================================================================*
	  Motor Parameter Definition
 *===================================================================*/

/* PWM Parameter */
#define	cPWMPRD_CH0 				(64.0f)				/* [us] PWM Period */
#define	cDEADTIME_CH0				(0.5f)				/* [us] Dead time */
#define	cREPTIME_CH0				(1)					/* Repeat time */

/* External specification */
#define	cSPEED_ACT_MIN_CH0			(12)				/* [Hz] Min Target speed of motor */
#define	cSPEED_ACT_MAX_CH0			(200) 				/* [Hz] Max Target speed of motor */

#define	cID_ST_USER_ACT_CH0			(0.2f)				/* [A] Start current (Id) */
#define	cIQ_ST_USER_ACT_CH0			(0.1f)				/* [A] Start current (Iq) */

/* Motor Parameter */
#define	cMOTOR_R_CH0				(11.0f)				/* [Ohm] Winding resistance */
#define	cMOTOR_LQ_CH0				(7.00f)				/* [mH] q-axis inductance */
#define	cMOTOR_LD_CH0				(cMOTOR_LQ_CH0)		/* [mH] d-axis inductance */
#define	cPOLE_CH0					(4)					/* [Pole] Poles of the motor */

/* Control Gain constant */
#define	cID_KP_CH0					(0.0219f)			/* [V/A]  d-axis current control Proportinal gain */
#define	cID_KI_CH0					(70.30f)			/* [V/As] d-axis current control Integral gain */
#define	cIQ_KP_CH0					(cID_KP_CH0)		/* [V/A]  q-axis current control Proportinal gain */
#define	cIQ_KI_CH0					(cID_KI_CH0)		/* [V/As] q-axis current control Integral gain */

#define	cPOSITION_KP_CH0			(5.00f)				/* [Hz/V]  Position estimation Proportinal gain (Kp) */
#define	cPOSITION_KI_CH0			(25.0f)				/* [Hz/Vs] Position estimation Integral gain (Ki) */
#define	cSPEED_KP_CH0				(0.015f)			/* [A/Hz]  Speed Control Proportinal gain */
#define	cSPEED_KI_CH0				(0.015f)			/* [A/Hzs] Speed Control Integral gain */

#define	cSPD_PI_PRD_CH0				(1)					/* Speed PI period */

#define	cFCD_UD_LIM_CH0				(15.0f)				/* [Hz/s] Limitation of the increase value (Forced Stage) */
#define	cSTD_UP_LIM_CH0				(10.0f)				/* [Hz/s] Limitation of the increase value (Steady Stage) */
#define	cSTD_DW_LIM_CH0				(10.0f)				/* [Hz/s] Limitation of the decrease value (Steady Stage) */

#define	cBOOT_LEN_CH0				(0.1f)				/* [s] Time of Bootstrap Stage */
#define	cINIT_LEN_CH0				(0.5f)				/* [s] Time of Positioning Stage */
#define	cINIT_WAIT_LEN_CH0			(0.5f)				/* [s] Time of Positioning wait time */
#define	cGOUP_DELAY_LEN_CH0			(0.01f)				/* [s] Time of Change-up delay time */

#define	cHZ_MAX_CH0 				(220.0f)	   		/* [Hz] Maximum speed of motor */
#define	cHZ_MIN_CH0 				(40.0f)				/* [Hz] Minimam speed of motor */
														/* When set cHZ_MIN > S_speed_actx, not move Stage from Force */

#define	cHZ_SPWM_CH0				(100.0f)			/* [Hz] in Hz the rotating speed under which the shift PWM will work (for VE 1shunt) */
#define	cMINPLS_CH0					(2.0f) 				/* [us] Minimum Pulse (for 1shunt) */
#define	cMAXPLS_CH0					(cPWMPRD_CH0 * 0.9f)	/* [us] Maximum Pulse (for 3shunt) */

#define	cID_LIM_CH0 				(cOVC_CH0 * 0.9f) 	/* [A] d-axis limitation current */
#define	cIQ_LIM_CH0 				(cOVC_CH0 * 0.9f) 	/* [A] q-axis limitation current */

#define	cINITIAL_POSITION_CH0		(0)					/* [deg] Initial position */

#if (cSHUNT_TYPE_CH0 == 3)
  #define	cTRG_COMP_CH0			(0.0f)  			/* [us] Trigger compensation time for 3shunt(for SoftVector). Setting range:0 <= x < (cPWMPRD_CH0/2) */
#else
  #define	cTRG_COMP_CH0			(-1.0f)				/* [us] Trigger compensation time for 1shunt(for SoftVector). Setting range:(-cPWMPRD_CH0/2) < x < (cPWMPRD_CH0/2) */
#endif

/*for Voltage control parameter */
#define	cVD_POS_CH0					(0.6f)				/* [V] Voltage of positioning */
#define	cSPD_COEF_CH0				(0.15f)				/* [-] Speed coefficient */
#define	cHZ_V2I_CH0					(100.0f)			/* [Hz] Speed of switching from voltage control to current control */

/* for Encoder parameter */
#define	cENC_PULSE_NUM_CH0			(2048)				/* [ppr] Number of Encoder pulse */
#define	cENC_DEG_ADJUST_CH0			(180)				/* [deg] Adjust Z-phase,0deg of electrical-angle */

#define	cENC_NOISE_TIME_CH0			(0.1f)				/* [us] Encoder signal input noise cancel time. unit:fc/8 (66.7ns@120MHz) Max:8.4us@120MHz (for A-ENC only) */

/* for Fixed Vdc parameter */
#define __FIXED_VDC_CH0 			(0)					/* Fixed Vdc */
#define	cVDC_CH0					(24.0f)				/* [V] Power Voltage */



/*===================================================================*/
/* Control period of motor */
#define	cCTRL_PRD_CH0				(cPWMPRD_CH0 * cREPTIME_CH0 * 1e-6)								/* [s] */
#define	cSPD_CTRL_PRD_CH0			(cSPD_PI_PRD_CH0 * cPWMPRD_CH0 * cREPTIME_CH0 * 1e-6)			/* [s] */


/*===================================================================*
	Parameter check
 *===================================================================*/
#if (!((cPOLH_CH0 == 0) || (cPOLH_CH0 == 1)))
#error cPOLH_CH0 define error. cPOLH_CH0 only 0 or 1.
#endif
#if (!((cPOLL_CH0 == 0) || (cPOLL_CH0 == 1)))
#error cPOLL_CH0 define error. cPOLL_CH0 only 0 or 1.
#endif


#if (!((cSHUNT_TYPE_CH0 == 1) || (cSHUNT_TYPE_CH0 == 3)))
#error cSHUNT_TYPE_CH0 define error. cSHUNT_TYPE_CH0 only 1 or 3.
#endif

#if defined(__TYPE_LOW_VOLT) && defined(__TYPE_HIGH_VOLT)
#error __TYPE_LOW_VOLT or __TYPE_HIGH_VOLT define error.
#endif


#endif /* _D_PARA_CH0_H */

/*************************** END OF FILE **************************************/

