;/**
; *******************************************************************************
; * @file    startup_TMPM4K4A.s
; * @brief   CMSIS Cortex-M4 Core Device Startup File for the
; *          TOSHIBA 'TMPM4K4A' Device Series
; * @version V0.0.0.0
; * $Date:: 2017-07-13 #$
; *------- <<< Use Configuration Wizard in Context Menu >>> ------------------
; * 
; * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
; * 
; * Copyright(C) Toshiba Electronic Device Solutions Corporation 2019
; *******************************************************************************
; */

; <h> Stack Configuration
;   <o> Stack Size (in Bytes) <0x0-0xFFFFFFFF:8>
; </h>

Stack_Size      EQU     0x00000200

                AREA    STACK, NOINIT, READWRITE, ALIGN=3
Stack_Mem       SPACE   Stack_Size
__initial_sp


; <h> Heap Configuration
;   <o>  Heap Size (in Bytes) <0x0-0xFFFFFFFF:8>
; </h>

Heap_Size       EQU     0x00000000

                AREA    HEAP, NOINIT, READWRITE, ALIGN=3
__heap_base
Heap_Mem        SPACE   Heap_Size
__heap_limit


                PRESERVE8
                THUMB


; Vector Table Mapped to Address 0 at Reset

                AREA    RESET, DATA, READONLY
                EXPORT  __Vectors

__Vectors       DCD     __initial_sp              ; Top of Stack
                DCD     Reset_Handler             ; Reset Handler
                DCD     NMI_Handler               ; NMI Handler
                DCD     HardFault_Handler         ; Hard Fault Handler
                DCD     MemManage_Handler         ; MPU Fault Handler
                DCD     BusFault_Handler          ; Bus Fault Handler
                DCD     UsageFault_Handler        ; Usage Fault Handler
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     SVC_Handler               ; SVCall Handler
                DCD     DebugMon_Handler          ; Debug Monitor Handler
                DCD     0                         ; Reserved
                DCD     PendSV_Handler            ; PendSV Handler
                DCD     SysTick_Handler           ; SysTick Handler

                ; External Interrupts
                DCD     INT00_IRQHandler          ; 0:	Interrupt Pin0
                DCD     INT01_IRQHandler          ; 1:	Interrupt Pin1
                DCD     INT02_IRQHandler          ; 2:	Interrupt Pin2
                DCD     INT03_IRQHandler          ; 3:	Interrupt Pin3
                DCD     INT04_IRQHandler          ; 4:	Interrupt Pin4
                DCD     INT05_IRQHandler          ; 5:	Interrupt Pin5
                DCD     INT06_IRQHandler          ; 6:	Interrupt Pin6
                DCD     INT07_IRQHandler          ; 7:	Interrupt Pin7
                DCD     INT08_IRQHandler          ; 8:	Interrupt Pin8
                DCD     INT09_IRQHandler          ; 9:	Interrupt Pin9
                DCD     INT10_IRQHandler          ; 10:	Interrupt Pin10
                DCD     INTVCN0_IRQHandler        ; 11:	A-VE interrupt 0
                DCD     INTVCT0_IRQHandler        ; 12:	A-VE task termination interrupt 0
                DCD     INTEMG0_IRQHandler        ; 13:	PMD0 EMG interrupt
                DCD     INTEMG1_IRQHandler        ; 14:	PMD1 EMG interrupt
                DCD     INTOVV0_IRQHandler        ; 15:	PMD0 OVV interrupt
                DCD     INTOVV1_IRQHandler        ; 16:	PMD1 OVV interrupt
                DCD     INTPWM0_IRQHandler        ; 17:	PMD0 PWM interrupt
                DCD     INTPWM1_IRQHandler        ; 18:	PMD1 PWM interrupt
                DCD     INTENC00_IRQHandler       ; 19:	Encoder 0 interrupt 0
                DCD     INTENC01_IRQHandler       ; 20:	Encoder 0 interrupt 1
                DCD     INTADPDA_IRQHandler       ; 21:	ADC conversion triggered by PMD is finished A
                DCD     INTADPDB_IRQHandler       ; 22:	ADC conversion triggered by PMD is finished B
                DCD     INTADPDC_IRQHandler       ; 23:	ADC conversion triggered by PMD is finished C
                DCD     INTADPDD_IRQHandler       ; 24:	ADC conversion triggered by PMD is finished D
                DCD     INTADPFLG_IRQHandler      ; 25:	ADC Priority interrupt
                DCD     INTADCP0_IRQHandler       ; 26:	ADC conversion monitoring function interrupt 0
                DCD     INTADCP1_IRQHandler       ; 27:	ADC conversion monitoring function interrupt 1
                DCD     INTADTRG_IRQHandler       ; 28:	ADC conversion triggered by General purpose is finished
                DCD     INTADSGL_IRQHandler       ; 29:	ADC conversion triggered by Single program is finished
                DCD     INTADCNT_IRQHandler       ; 30:	ADC conversion triggered by Continuity program is finished
                DCD     INTSC0RX_IRQHandler       ; 31:	TSPI0 / UART0 reception interrupt
                DCD     INTSC0TX_IRQHandler       ; 32:	TSPI0 / UART0 transmit interrupt
                DCD     INTSC0ERR_IRQHandler      ; 33:	TSPI0 / UART0 error interrupt
                DCD     INTSC1RX_IRQHandler       ; 34:	TSPI1 / UART1 reception interrupt
                DCD     INTSC1TX_IRQHandler       ; 35:	TSPI1 / UART1 transmit interrupt
                DCD     INTSC1ERR_IRQHandler      ; 36:	TSPI1 / UART1 error interrupt
                DCD     INTSC2RX_IRQHandler       ; 37:	TSPI2 / UART2 reception interrupt
                DCD     INTSC2TX_IRQHandler       ; 38:	TSPI2 / UART2 transmit interrupt
                DCD     INTSC2ERR_IRQHandler      ; 39:	TSPI2 / UART2 error interrupt
                DCD     INTSC3RX_IRQHandler       ; 40:	TSPI3 / UART3 reception interrupt
                DCD     INTSC3TX_IRQHandler       ; 41:	TSPI3 / UART3 transmit interrupt
                DCD     INTSC3ERR_IRQHandler      ; 42:	TSPI3 / UART3 error interrupt
                DCD     INTI2C0_IRQHandler        ; 43:	I2C0 transmission and reception interrupt
                DCD     INTI2C0AL_IRQHandler      ; 44:	I2C0 arbitration lost interrupt
                DCD     INTI2C0BF_IRQHandler      ; 45:	I2C0 bus free interrupt
                DCD     INTI2C0NA_IRQHandler      ; 46:	I2C0 no ack interrupt
                DCD     INTT32A0AC_IRQHandler     ; 47:	T32A0 TimmerA/C compare match detection / Over flow / under flow
                DCD     INTT32A0ACCAP0_IRQHandler ; 48:	T32A0 TimmerA/C input capture 0
                DCD     INTT32A0ACCAP1_IRQHandler ; 49:	T32A0 TimmerA/C input capture 1
                DCD     INTT32A0B_IRQHandler      ; 50:	T32A0 TimmerB compare match detection / Over flow / under flow
                DCD     INTT32A0BCAP0_IRQHandler  ; 51:	T32A0 TimmerB input capture 0
                DCD     INTT32A0BCAP1_IRQHandler  ; 52:	T32A0 TimmerB input capture 1
                DCD     INTT32A1AC_IRQHandler     ; 53:	T32A1 TimmerA/C compare match detection / Over flow / under flow
                DCD     INTT32A1ACCAP0_IRQHandler ; 54:	T32A1 TimmerA/C input capture 0
                DCD     INTT32A1ACCAP1_IRQHandler ; 55:	T32A1 TimmerA/C input capture 1
                DCD     INTT32A1B_IRQHandler      ; 56:	T32A1 TimmerB compare match detection / Over flow / under flow
                DCD     INTT32A1BCAP0_IRQHandler  ; 57:	T32A1 TimmerB input capture 0
                DCD     INTT32A1BCAP1_IRQHandler  ; 58:	T32A1 TimmerB input capture 1
                DCD     INTT32A2AC_IRQHandler     ; 59:	T32A2 TimmerA/C compare match detection / Over flow / under flow
                DCD     INTT32A2ACCAP0_IRQHandler ; 60:	T32A2 TimmerA/C input capture 0
                DCD     INTT32A2ACCAP1_IRQHandler ; 61:	T32A2 TimmerA/C input capture 1
                DCD     INTT32A2B_IRQHandler      ; 62:	T32A2 TimmerB compare match detection / Over flow / under flow
                DCD     INTT32A2BCAP0_IRQHandler  ; 63:	T32A2 TimmerB input capture 0
                DCD     INTT32A2BCAP1_IRQHandler  ; 64:	T32A2 TimmerB input capture 1
                DCD     INTT32A3AC_IRQHandler     ; 65:	T32A3 TimmerA/C compare match detection / Over flow / under flow
                DCD     INTT32A3ACCAP0_IRQHandler ; 66:	T32A3 TimmerA/C input capture 0
                DCD     INTT32A3ACCAP1_IRQHandler ; 67:	T32A3 TimmerA/C input capture 1
                DCD     INTT32A3B_IRQHandler      ; 68:	T32A3 TimmerB compare match detection / Over flow / under flow
                DCD     INTT32A3BCAP0_IRQHandler  ; 69:	T32A3 TimmerB input capture 0
                DCD     INTT32A3BCAP1_IRQHandler  ; 70:	T32A3 TimmerB input capture 1
                DCD     INTT32A4AC_IRQHandler     ; 71:	T32A4 TimmerA/C compare match detection / Over flow / under flow
                DCD     INTT32A4ACCAP0_IRQHandler ; 72:	T32A4 TimmerA/C input capture 0
                DCD     INTT32A4ACCAP1_IRQHandler ; 73:	T32A4 TimmerA/C input capture 1
                DCD     INTT32A4B_IRQHandler      ; 74:	T32A4 TimmerB compare match detection / Over flow / under flow
                DCD     INTT32A4BCAP0_IRQHandler  ; 75:	T32A4 TimmerB input capture 0
                DCD     INTT32A4BCAP1_IRQHandler  ; 76:	T32A4 TimmerB input capture 1
                DCD     INTT32A5AC_IRQHandler     ; 77:	T32A5 TimmerA/C compare match detection / Over flow / under flow
                DCD     INTT32A5ACCAP0_IRQHandler ; 78:	T32A5 TimmerA/C input capture 0
                DCD     INTT32A5ACCAP1_IRQHandler ; 79:	T32A5 TimmerA/C input capture 1
                DCD     INTT32A5B_IRQHandler      ; 80:	T32A5 TimmerB compare match detection / Over flow / under flow
                DCD     INTT32A5BCAP0_IRQHandler  ; 81:	T32A5 TimmerB input capture 0
                DCD     INTT32A5BCAP1_IRQHandler  ; 82:	T32A5 TimmerB input capture 1
                DCD     INTPARI_IRQHandler        ; 83:	RAM parity interrupt
                DCD     INTDMAATC_IRQHandler      ; 84:	DMA end of transfer
                DCD     INTDMAAERR_IRQHandler     ; 85:	DMA transfer error
                DCD     0                         ; 86:	Reserved
                DCD     INTFLCRDY_IRQHandler      ; 87:	Code FLASH Ready interrupt
                DCD     0                         ; 88:	Reserved



                AREA    |.text|, CODE, READONLY


; Reset Handler

Reset_Handler   PROC
                EXPORT  Reset_Handler             [WEAK]
                IMPORT  SystemInit
                IMPORT  __main
                LDR     R0, =SystemInit
                BLX     R0
                LDR     R0, =__main
                BX      R0
                ENDP


; Dummy Exception Handlers (infinite loops which can be modified)

NMI_Handler     PROC
                EXPORT  NMI_Handler               [WEAK]
                B       .
                ENDP
HardFault_Handler\
                PROC
                EXPORT  HardFault_Handler         [WEAK]
                B       .
                ENDP
MemManage_Handler\
                PROC
                EXPORT  MemManage_Handler         [WEAK]
                B       .
                ENDP
BusFault_Handler\
                PROC
                EXPORT  BusFault_Handler          [WEAK]
                B       .
                ENDP
UsageFault_Handler\
                PROC
                EXPORT  UsageFault_Handler        [WEAK]
                B       .
                ENDP
SVC_Handler     PROC
                EXPORT  SVC_Handler               [WEAK]
                B       .
                ENDP
DebugMon_Handler\
                PROC
                EXPORT  DebugMon_Handler          [WEAK]
                B       .
                ENDP
PendSV_Handler  PROC
                EXPORT  PendSV_Handler            [WEAK]
                B       .
                ENDP
SysTick_Handler PROC
                EXPORT  SysTick_Handler           [WEAK]
                B       .
                ENDP

Default_Handler PROC

                EXPORT  INT00_IRQHandler          [WEAK]
                EXPORT  INT01_IRQHandler          [WEAK]
                EXPORT  INT02_IRQHandler          [WEAK]
                EXPORT  INT03_IRQHandler          [WEAK]
                EXPORT  INT04_IRQHandler          [WEAK]
                EXPORT  INT05_IRQHandler          [WEAK]
                EXPORT  INT06_IRQHandler          [WEAK]
                EXPORT  INT07_IRQHandler          [WEAK]
                EXPORT  INT08_IRQHandler          [WEAK]
                EXPORT  INT09_IRQHandler          [WEAK]
                EXPORT  INT10_IRQHandler          [WEAK]
                EXPORT  INTVCN0_IRQHandler        [WEAK]
                EXPORT  INTVCT0_IRQHandler        [WEAK]
                EXPORT  INTEMG0_IRQHandler        [WEAK]
                EXPORT  INTEMG1_IRQHandler        [WEAK]
                EXPORT  INTOVV0_IRQHandler        [WEAK]
                EXPORT  INTOVV1_IRQHandler        [WEAK]
                EXPORT  INTPWM0_IRQHandler        [WEAK]
                EXPORT  INTPWM1_IRQHandler        [WEAK]
                EXPORT  INTENC00_IRQHandler       [WEAK]
                EXPORT  INTENC01_IRQHandler       [WEAK]
                EXPORT  INTADPDA_IRQHandler       [WEAK]
                EXPORT  INTADPDB_IRQHandler       [WEAK]
                EXPORT  INTADPDC_IRQHandler       [WEAK]
                EXPORT  INTADPDD_IRQHandler       [WEAK]
                EXPORT  INTADPFLG_IRQHandler      [WEAK]
                EXPORT  INTADCP0_IRQHandler       [WEAK]
                EXPORT  INTADCP1_IRQHandler       [WEAK]
                EXPORT  INTADTRG_IRQHandler       [WEAK]
                EXPORT  INTADSGL_IRQHandler       [WEAK]
                EXPORT  INTADCNT_IRQHandler       [WEAK]
                EXPORT  INTSC0RX_IRQHandler       [WEAK]
                EXPORT  INTSC0TX_IRQHandler       [WEAK]
                EXPORT  INTSC0ERR_IRQHandler      [WEAK]
                EXPORT  INTSC1RX_IRQHandler       [WEAK]
                EXPORT  INTSC1TX_IRQHandler       [WEAK]
                EXPORT  INTSC1ERR_IRQHandler      [WEAK]
                EXPORT  INTSC2RX_IRQHandler       [WEAK]
                EXPORT  INTSC2TX_IRQHandler       [WEAK]
                EXPORT  INTSC2ERR_IRQHandler      [WEAK]
                EXPORT  INTSC3RX_IRQHandler       [WEAK]
                EXPORT  INTSC3TX_IRQHandler       [WEAK]
                EXPORT  INTSC3ERR_IRQHandler      [WEAK]
                EXPORT  INTI2C0_IRQHandler        [WEAK]
                EXPORT  INTI2C0AL_IRQHandler      [WEAK]
                EXPORT  INTI2C0BF_IRQHandler      [WEAK]
                EXPORT  INTI2C0NA_IRQHandler      [WEAK]
                EXPORT  INTT32A0AC_IRQHandler     [WEAK]
                EXPORT  INTT32A0ACCAP0_IRQHandler [WEAK]
                EXPORT  INTT32A0ACCAP1_IRQHandler [WEAK]
                EXPORT  INTT32A0B_IRQHandler      [WEAK]
                EXPORT  INTT32A0BCAP0_IRQHandler  [WEAK]
                EXPORT  INTT32A0BCAP1_IRQHandler  [WEAK]
                EXPORT  INTT32A1AC_IRQHandler     [WEAK]
                EXPORT  INTT32A1ACCAP0_IRQHandler [WEAK]
                EXPORT  INTT32A1ACCAP1_IRQHandler [WEAK]
                EXPORT  INTT32A1B_IRQHandler      [WEAK]
                EXPORT  INTT32A1BCAP0_IRQHandler  [WEAK]
                EXPORT  INTT32A1BCAP1_IRQHandler  [WEAK]
                EXPORT  INTT32A2AC_IRQHandler     [WEAK]
                EXPORT  INTT32A2ACCAP0_IRQHandler [WEAK]
                EXPORT  INTT32A2ACCAP1_IRQHandler [WEAK]
                EXPORT  INTT32A2B_IRQHandler      [WEAK]
                EXPORT  INTT32A2BCAP0_IRQHandler  [WEAK]
                EXPORT  INTT32A2BCAP1_IRQHandler  [WEAK]
                EXPORT  INTT32A3AC_IRQHandler     [WEAK]
                EXPORT  INTT32A3ACCAP0_IRQHandler [WEAK]
                EXPORT  INTT32A3ACCAP1_IRQHandler [WEAK]
                EXPORT  INTT32A3B_IRQHandler      [WEAK]
                EXPORT  INTT32A3BCAP0_IRQHandler  [WEAK]
                EXPORT  INTT32A3BCAP1_IRQHandler  [WEAK]
                EXPORT  INTT32A4AC_IRQHandler     [WEAK]
                EXPORT  INTT32A4ACCAP0_IRQHandler [WEAK]
                EXPORT  INTT32A4ACCAP1_IRQHandler [WEAK]
                EXPORT  INTT32A4B_IRQHandler      [WEAK]
                EXPORT  INTT32A4BCAP0_IRQHandler  [WEAK]
                EXPORT  INTT32A4BCAP1_IRQHandler  [WEAK]
                EXPORT  INTT32A5AC_IRQHandler     [WEAK]
                EXPORT  INTT32A5ACCAP0_IRQHandler [WEAK]
                EXPORT  INTT32A5ACCAP1_IRQHandler [WEAK]
                EXPORT  INTT32A5B_IRQHandler      [WEAK]
                EXPORT  INTT32A5BCAP0_IRQHandler  [WEAK]
                EXPORT  INTT32A5BCAP1_IRQHandler  [WEAK]
                EXPORT  INTPARI_IRQHandler        [WEAK]
                EXPORT  INTDMAATC_IRQHandler      [WEAK]
                EXPORT  INTDMAAERR_IRQHandler     [WEAK]
                EXPORT  INTFLCRDY_IRQHandler      [WEAK]

INT00_IRQHandler
INT01_IRQHandler
INT02_IRQHandler
INT03_IRQHandler
INT04_IRQHandler
INT05_IRQHandler
INT06_IRQHandler
INT07_IRQHandler
INT08_IRQHandler
INT09_IRQHandler
INT10_IRQHandler
INTVCN0_IRQHandler
INTVCT0_IRQHandler
INTEMG0_IRQHandler
INTEMG1_IRQHandler
INTOVV0_IRQHandler
INTOVV1_IRQHandler
INTPWM0_IRQHandler
INTPWM1_IRQHandler
INTENC00_IRQHandler
INTENC01_IRQHandler
INTADPDA_IRQHandler
INTADPDB_IRQHandler
INTADPDC_IRQHandler
INTADPDD_IRQHandler
INTADPFLG_IRQHandler
INTADCP0_IRQHandler
INTADCP1_IRQHandler
INTADTRG_IRQHandler
INTADSGL_IRQHandler
INTADCNT_IRQHandler
INTSC0RX_IRQHandler
INTSC0TX_IRQHandler
INTSC0ERR_IRQHandler
INTSC1RX_IRQHandler
INTSC1TX_IRQHandler
INTSC1ERR_IRQHandler
INTSC2RX_IRQHandler
INTSC2TX_IRQHandler
INTSC2ERR_IRQHandler
INTSC3RX_IRQHandler
INTSC3TX_IRQHandler
INTSC3ERR_IRQHandler
INTI2C0_IRQHandler
INTI2C0AL_IRQHandler
INTI2C0BF_IRQHandler
INTI2C0NA_IRQHandler
INTT32A0AC_IRQHandler
INTT32A0ACCAP0_IRQHandler
INTT32A0ACCAP1_IRQHandler
INTT32A0B_IRQHandler
INTT32A0BCAP0_IRQHandler
INTT32A0BCAP1_IRQHandler
INTT32A1AC_IRQHandler
INTT32A1ACCAP0_IRQHandler
INTT32A1ACCAP1_IRQHandler
INTT32A1B_IRQHandler
INTT32A1BCAP0_IRQHandler
INTT32A1BCAP1_IRQHandler
INTT32A2AC_IRQHandler
INTT32A2ACCAP0_IRQHandler
INTT32A2ACCAP1_IRQHandler
INTT32A2B_IRQHandler
INTT32A2BCAP0_IRQHandler
INTT32A2BCAP1_IRQHandler
INTT32A3AC_IRQHandler
INTT32A3ACCAP0_IRQHandler
INTT32A3ACCAP1_IRQHandler
INTT32A3B_IRQHandler
INTT32A3BCAP0_IRQHandler
INTT32A3BCAP1_IRQHandler
INTT32A4AC_IRQHandler
INTT32A4ACCAP0_IRQHandler
INTT32A4ACCAP1_IRQHandler
INTT32A4B_IRQHandler
INTT32A4BCAP0_IRQHandler
INTT32A4BCAP1_IRQHandler
INTT32A5AC_IRQHandler
INTT32A5ACCAP0_IRQHandler
INTT32A5ACCAP1_IRQHandler
INTT32A5B_IRQHandler
INTT32A5BCAP0_IRQHandler
INTT32A5BCAP1_IRQHandler
INTPARI_IRQHandler
INTDMAATC_IRQHandler
INTDMAAERR_IRQHandler
INTFLCRDY_IRQHandler

                B       .

                ENDP


                ALIGN


; User Initial Stack & Heap

                IF      :DEF:__MICROLIB

                EXPORT  __initial_sp
                EXPORT  __heap_base
                EXPORT  __heap_limit

                ELSE

                IMPORT  __use_two_region_memory
                EXPORT  __user_initial_stackheap
__user_initial_stackheap

                LDR     R0, =  Heap_Mem
                LDR     R1, =(Stack_Mem + Stack_Size)
                LDR     R2, = (Heap_Mem +  Heap_Size)
                LDR     R3, = Stack_Mem
                BX      LR

                ALIGN

                ENDIF


                END

