/**
 *******************************************************************************
 * @file    ipdrv_cg.h
 * @brief   This file provides all the functions prototypes for M4Kx CG driver.
 * @version V1.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2019
 *******************************************************************************
 */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __IPDRV_CG_H
#define __IPDRV_CG_H

#ifdef __cplusplus
extern "C" {
#endif                          /* __cplusplus */

/* Includes ------------------------------------------------------------------*/
#include "TMPM4KxA.h"
#include "ipdrv_common.h"

/** @addtogroup TX04_Periph_Driver
  * @{
  */

/** @addtogroup CG
  * @{
  */

/** @addtogroup CG_Exported_types
  * @{
  */

#define CG_FC_PERIPH_PORTA      (0x00000001U << 0U)
#define CG_FC_PERIPH_PORTB      (0x00000001U << 1U)
#define CG_FC_PERIPH_PORTC      (0x00000001U << 2U)
#define CG_FC_PERIPH_PORTD      (0x00000001U << 3U)
#define CG_FC_PERIPH_PORTE      (0x00000001U << 4U)
#define CG_FC_PERIPH_PORTF      (0x00000001U << 5U)
#define CG_FC_PERIPH_PORTG      (0x00000001U << 6U)
#define CG_FC_PERIPH_PORTH      (0x00000001U << 7U)
#define CG_FC_PERIPH_PORTJ      (0x00000001U << 8U)
#define CG_FC_PERIPH_PORTK      (0x00000001U << 9U)
#define CG_FC_PERIPH_PORTL      (0x00000001U << 10U)

#define CG_FC_PERIPH_TSPI0      (0x00000001U << 16U)
#define CG_FC_PERIPH_TSPI1      (0x00000001U << 17U)
#define CG_FC_PERIPH_TSPI2      (0x00000001U << 18U)
#define CG_FC_PERIPH_TSPI3      (0x00000001U << 19U)
#define CG_FC_PERIPH_UART0      (0x00000001U << 20U)
#define CG_FC_PERIPH_UART1      (0x00000001U << 21U)
#define CG_FC_PERIPH_UART2      (0x00000001U << 22U)
#define CG_FC_PERIPH_UART3      (0x00000001U << 23U)
#define CG_FC_PERIPH_I2C        (0x00000001U << 24U)
#define CG_FC_PERIPH_T32A0      (0x00000001U << 25U)
#define CG_FC_PERIPH_T32A1      (0x00000001U << 26U)
#define CG_FC_PERIPH_T32A2      (0x00000001U << 27U)
#define CG_FC_PERIPH_T32A3      (0x00000001U << 28U)
#define CG_FC_PERIPH_T32A4      (0x00000001U << 29U)
#define CG_FC_PERIPH_T32A5      (0x00000001U << 30U)
#define CG_FC_PERIPH_RTC        (0x00000001U << 31U)
#define CG_FC_PERIPHA_ALL       (0xFFFF07FFU)
#define IS_CG_FC_PERIPHA(param) (((param) > 0U) && ((param) <= CG_FC_PERIPHA_ALL))


#define CG_FC_PERIPH_ADC0       (0x00000001U << 0U)
#define CG_FC_PERIPH_ADC1       (0x00000001U << 1U)
#define CG_FC_PERIPH_AMP        (0x00000001U << 2U)
#define CG_FC_PERIPH_CMP        (0x00000001U << 3U)
#define CG_FC_PERIPH_DAC0       (0x00000001U << 4U)
#define CG_FC_PERIPH_DAC1       (0x00000001U << 5U)
#define CG_FC_PERIPH_DAC2       (0x00000001U << 6U)
#define CG_FC_PERIPH_A_ENC      (0x00000001U << 7U)
#define CG_FC_PERIPH_PMD0       (0x00000001U << 8U)
#define CG_FC_PERIPH_PMD1       (0x00000001U << 9U)
#define CG_FC_PERIPH_A_VE_P     (0x00000001U << 10U)
#define CG_FC_PERIPH_RAM_PARI   (0x00000001U << 11U)
#define CG_FC_PERIPH_CRC        (0x00000001U << 12U)
#define CG_FC_PERIPH_OFD        (0x00000001U << 13U)
#define CG_FC_PERIPH_TRIM       (0x00000001U << 14U)
#define CG_FC_PERIPH_TRGSEL     (0x00000001U << 15U)
#define CG_FC_PERIPH_DMAC       (0x00000001U << 16U)

#define CG_FC_PERIPH_SIWDT      (0x00000001U << 31U)
#define CG_FC_PERIPHB_ALL       (0xF001FFFFU)
#define IS_CG_FC_PERIPHB(param) (((param) > 0U) && ((param) <= CG_FC_PERIPHB_ALL))

#define CG_FC_PERIPH_DNFCK      (0x00000001U << 7U)
#define CG_FC_PERIPH_ALL        (0x00000080U)
#define IS_CG_FC_PERIPH(param)  (((param) > 0U) && ((param) <= CG_FC_PERIPH_ALL))


/** @} */
/* End of group CG_Exported_types */

/** @defgroup CG_Exported_FunctionPrototypes
  * @{
  */
    void CG_SetFsysSupplyPeriphA(uint32_t Periph, FunctionalState NewState);
    void CG_SetFsysSupplyPeriphB(uint32_t Periph, FunctionalState NewState);
    void CG_SetFcSupplyPeriph(uint32_t Periph, FunctionalState NewState);
    void CG_SetAdcClkSupply(FunctionalState NewState);

/** @} */
/* End of group CG_Exported_FunctionPrototype */

/** @} */
/* End of group CG */

/** @} */
/* End of group TX04_Periph_Driver */

#ifdef __cplusplus
}
#endif                          /* __cplusplus */
#endif                          /* __IPDRV_CG_H */
